mailr19121 - in /trunk: lib/structure/represent/ test_suite/unit_tests/_lib/_structure/_represent/


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on March 24, 2013 - 16:56:
Author: bugman
Date: Sun Mar 24 16:56:29 2013
New Revision: 19121

URL: http://svn.gna.org/viewcvs/relax?rev=19121&view=rev
Log:
Created the empty lib.structure.represent package.

This will be used to hold modules which generate 3D structures as geometric 
representations of
abstract ideas such as tensors, cones, frames, etc.


Added:
    trunk/lib/structure/represent/
    trunk/lib/structure/represent/__init__.py
      - copied, changed from r19119, trunk/lib/structure/internal/__init__.py
    trunk/test_suite/unit_tests/_lib/_structure/_represent/
      - copied from r19118, 
trunk/test_suite/unit_tests/_lib/_structure/_internal/
Modified:
    trunk/test_suite/unit_tests/_lib/_structure/_represent/test___init__.py

Copied: trunk/lib/structure/represent/__init__.py (from r19119, 
trunk/lib/structure/internal/__init__.py)
URL: 
http://svn.gna.org/viewcvs/relax/trunk/lib/structure/represent/__init__.py?p2=trunk/lib/structure/represent/__init__.py&p1=trunk/lib/structure/internal/__init__.py&r1=19119&r2=19121&rev=19121&view=diff
==============================================================================
--- trunk/lib/structure/internal/__init__.py (original)
+++ trunk/lib/structure/represent/__init__.py Sun Mar 24 16:56:29 2013
@@ -20,9 +20,11 @@
 
###############################################################################
 
 # Package docstring.
-"""The relax-lib structure.internal package - the internal structural 
object."""
+"""The relax-lib structure.represent package - creation of structures 
representing abstract ideas.
+
+This includes tensors, cones, rotors, axis systems, etc.
+"""
 
 __all__ = [
-    'models',
-    'molecules'
+    ''
 ]

Modified: 
trunk/test_suite/unit_tests/_lib/_structure/_represent/test___init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/_structure/_represent/test___init__.py?rev=19121&r1=19118&r2=19121&view=diff
==============================================================================
--- trunk/test_suite/unit_tests/_lib/_structure/_represent/test___init__.py 
(original)
+++ trunk/test_suite/unit_tests/_lib/_structure/_represent/test___init__.py 
Sun Mar 24 16:56:29 2013
@@ -25,15 +25,15 @@
 
 # relax module imports.
 from test_suite.unit_tests.package_checking import PackageTestCase
-import lib.structure.internal
+import lib.structure.represent
 
 
 class Test___init__(PackageTestCase):
     """Unit tests for the lib.structure.internal package."""
 
     def setUp(self):
         """Set up for the package checking."""
 
-        self.package = lib.structure.internal
-        self.package_name = 'lib.structure.internal'
-        self.package_path = sys.path[0] + sep + 'lib' + sep + 'structure' + 
sep + 'internal'
+        self.package = lib.structure.represent
+        self.package_name = 'lib.structure.represent'
+        self.package_path = sys.path[0] + sep + 'lib' + sep + 'structure' + 
@@ -25,15 +25,15 @@
 
 class Test___init__(PackageTestCase):
-    """Unit tests for the lib.structure.internal package."""
+    """Unit tests for the lib.structure.represent package."""
 
     def setUp(self):
sep + 'represent'




Related Messages


Powered by MHonArc, Updated Sun Mar 24 17:00:02 2013